#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from airflow.models import DAG

from airflow.operators.bash_operator import BashOperator

import pendulum
from datetime import timedelta, datetime

# time zone을 한국 시간으로 설정하려면 pendulum 등의 library를 이용한다.
local_tz = pendulum.timezone("Asia/Seoul")

"""
triggered_dag.py는 TriggerDagRunOperator에 의해 기동되는 DAG를 정의하고 있다.
특수한 정의는 필요 없다.
"""

# DAG 객체에서 이용하는 공통된 인수를 정의한다.
default_args = {
    'owner': 'Airflow',
    'start_date': datetime(2019, 1, 1, tzinfo=pendulum.timezone('Asia/Seoul')),
    'depends_on_past': True,
    'retries': 1,
    'retry_delay': timedelta(minutes=5),
}

# DAG 객체를 정의한다.
# 여기서는 정기 실행의 정의(schedule_interval)를 '1회만'으로 하고 있다.
dag = DAG(
    dag_id='tirggered_dag',
    default_args=default_args,
    schedule_interval=None,
)

# tirgger_dag_run에서의 message를 BashOperator의 template로 받는다.
operator_1 = BashOperator(
    task_id="operator_1",
    bash_command='echo "Here is the message: {{ dag_run.conf["message"] }}" ',
    dag=dag,
)

operator_1
